aboutsummaryrefslogtreecommitdiffstats
path: root/camel/camel-mime-utils.h
diff options
context:
space:
mode:
Diffstat (limited to 'camel/camel-mime-utils.h')
-rw-r--r--camel/camel-mime-utils.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/camel/camel-mime-utils.h b/camel/camel-mime-utils.h
index 57d6d3ffb5..febd0f8dbe 100644
--- a/camel/camel-mime-utils.h
+++ b/camel/camel-mime-utils.h
@@ -91,8 +91,9 @@ void header_raw_clear(struct _header_raw **list);
/* decode a header which is a simple token */
char *header_token_decode(const char *in);
/* decode a string type, like a subject line */
char *header_decode_string(const char *in);
+char *header_encode_string(const unsigned char *in);
/* decode an email date field into a GMT time, + optional offset */
time_t header_decode_date(const char *in, int *saveoffset);
@@ -91,8 +91,9 @@ void header_raw_clear(struct _header_raw **list);
/* decode a header which is a simple token */
char *header_token_decode(const char *in);
-/* decode a string type, like a subject line */
+/* decode/encode a string type, like a subject line */
char *header_decode_string(const char *in);